@@ -14,7 +14,6 @@
 #include "resources/eventmodel.h"
 #include "lib/messagebox.h"
 #include "kalarmcalendar/kaevent.h"
-#include "kalarm_debug.h"
 
 #include <KFindDialog>
 #include <KFind>
@@ -26,7 +25,8 @@
 #include <QCheckBox>
 #include <QVBoxLayout>
 #include <QGridLayout>
-#include <QRegExp>
+#include <QRegularExpression>
+#include <kwidgetsaddons_version.h>
 
 using namespace KAlarmCal;
 
@@ -215,7 +215,7 @@ void Find::slotFind()
         return;
     mHistory = mDialog->findHistory();    // save search history so that it can be displayed again
     mOptions = mDialog->options() & ~FIND_KALARM_OPTIONS;
-    if ((mOptions & KFind::RegularExpression)  &&  !QRegExp(mDialog->pattern()).isValid())
+    if ((mOptions & KFind::RegularExpression)  &&  !QRegularExpression(mDialog->pattern()).isValid())
         return;
     mOptions |= (mLive->isEnabled()        && mLive->isChecked()        ? FIND_LIVE : 0)
              |  (mArchived->isEnabled()    && mArchived->isChecked()    ? FIND_ARCHIVED : 0)
@@ -227,7 +227,7 @@ void Find::slotFind()
     if (!(mOptions & (FIND_LIVE | FIND_ARCHIVED))
     ||  !(mOptions & (FIND_MESSAGE | FIND_FILE | FIND_COMMAND | FIND_EMAIL | FIND_AUDIO)))
     {
-        KAMessageBox::sorry(mDialog, i18nc("@info", "No alarm types are selected to search"));
+        KAMessageBox::error(mDialog, i18nc("@info", "No alarm types are selected to search"));
         return;
     }
 
@@ -378,7 +378,11 @@ void Find::findNext(bool forward, bool checkEnd, bool fromCurrent)
         {
             const QString msg = forward ? xi18nc("@info", "<para>End of alarm list reached.</para><para>Continue from the beginning?</para>")
                                         : xi18nc("@info", "<para>Beginning of alarm list reached.</para><para>Continue from the end?</para>");
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            if (KAMessageBox::questionYesNo(mListView, msg, QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel()) == KMessageBox::ButtonCode::PrimaryAction)
+#else
             if (KAMessageBox::questionYesNo(mListView, msg, QString(), KStandardGuiItem::cont(), KStandardGuiItem::cancel()) == KMessageBox::Yes)
+#endif
             {
                 mNoCurrentItem = true;
                 findNext(forward, false, false);
