@@ -33,15 +33,13 @@
 #include <KWindowSystem>
 #include <KSqueezedTextLabel>
 #include <KIdleTime>
-#if KDEPIM_HAVE_X11
+#if ENABLE_X11
 #include <KWindowInfo>
 #include <netwm.h>
-#if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
-#include <QGuiApplication>
-#elif QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-#include <private/qtx11extras_p.h>
-#else
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QX11Info>
+#else
+#include <QGuiApplication>
 #endif
 #endif
 #include <QTextBrowser>
@@ -56,7 +54,6 @@
 #include <QHBoxLayout>
 #include <QResizeEvent>
 #include <QCloseEvent>
-#include <QDesktopWidget>
 #include <QScreen>
 #include <QStyle>
 
@@ -1072,7 +1069,11 @@ bool MessageWindow::confirmAcknowledgement()
         // Ask for confirmation of acknowledgement. Use warningYesNo() because its default is No.
         if (KAMessageBox::warningYesNo(this, i18nc("@info", "Do you really want to acknowledge this alarm?"),
                                              i18nc("@action:button", "Acknowledge Alarm"), KGuiItem(i18nc("@action:button", "Acknowledge")), KStandardGuiItem::cancel())
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+            != KMessageBox::ButtonCode::PrimaryAction)
+#else
             != KMessageBox::Yes)
+#endif
         {
             return false;
         }
@@ -1126,7 +1127,7 @@ void MessageWindow::slotShowKMailMessage()
     }
 
     if (failed1 || failed2)
-        KAMessageBox::sorry(this, xi18nc("@info", "Unable to locate this email in <application>KMail</application>"));
+        KAMessageBox::error(this, xi18nc("@info", "Unable to locate this email in <application>KMail</application>"));
 }
 
 /******************************************************************************
@@ -1249,7 +1250,7 @@ bool MessageWindow::getWorkAreaAndModal()
         // There are multiple screens.
         // Check for any full screen windows, even if they are not the active
         // window, and try not to show the alarm message their screens.
-        mScreenNumber = QApplication::desktop()->screenNumber(MainWindow::mainMainWindow());  // default = KAlarm's screen
+        mScreenNumber = screens.indexOf(MainWindow::mainMainWindow()->screen());  // default = KAlarm's screen
         if (QGuiApplication::primaryScreen()->virtualSiblings().size() > 1)
         {
             // The screens form a single virtual desktop.
@@ -1338,7 +1339,7 @@ FullScreenType haveFullScreenWindow(int screen)
 {
     FullScreenType type = NoFullScreen;
 //TODO: implement on Wayland
-#if KDEPIM_HAVE_X11
+#if ENABLE_X11
     if (KWindowSystem::isPlatformX11())
     {
 #if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
@@ -1367,7 +1368,7 @@ FullScreenType haveFullScreenWindow(int screen)
             }
         }
     }
-#endif // KDEPIM_HAVE_X11
+#endif // ENABLE_X11
     return type;
 }
 
@@ -1380,7 +1381,7 @@ FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, QVector<
     FullScreenType result = NoFullScreen;
     screenTypes.fill(NoFullScreen);
 //TODO: implement on Wayland
-#if KDEPIM_HAVE_X11
+#if ENABLE_X11
     if (KWindowSystem::isPlatformX11())
     {
 #if QT_VERSION >= QT_VERSION_CHECK(6, 2, 0)
@@ -1430,7 +1431,7 @@ FullScreenType findFullScreenWindows(const QVector<QRect>& screenRects, QVector<
             }
         }
     }
-#endif // KDEPIM_HAVE_X11
+#endif // ENABLE_X11
     return result;
 }
 
